@@ -16,9 +16,10 @@ int main(int argc, char *argv[])
 
     langPath = "/opt/filebox/lang/";
 
+    // This shit returns the device language, not the current language
     //QString lang = QLocale::languageToString(QLocale::system().language());
 
-
+    // Open locale file to chech current language
     QString line, lang;
     QFile data( "/etc/osso-af-init/locale" );
     if (data.open(QFile::ReadOnly | QFile::Truncate))
@@ -34,12 +35,13 @@ int main(int argc, char *argv[])
             }
         }
     }
-    //lang = "es_ES";
     data.close();
 
+    // Convert en_GB to English, es_ES to Spanish...
     QLocale::setDefault(lang);
     lang = QLocale::languageToString(QLocale(lang).language());
 
+    // Install language file
     QTranslator translator;
     if (!lang.isEmpty() && !langPath.isEmpty())
     {
@@ -53,12 +55,6 @@ int main(int argc, char *argv[])
     QString folder(argv[1]);
     MainWindow* w = new MainWindow(0,folder);
 
-    //w.setAttribute(Qt::WA_Maemo5AutoOrientation, true);
-
-#if defined(Q_WS_S60)
-    w->showMaximized();
-#else
     w->show();
-#endif
     return a.exec();
 }
