@@ -136,10 +136,15 @@ MainWindow::MainWindow(QWidget *parent, QString openfolder) :
     }
     data.close();
 
-    if ( openfolder == "" )
-        CargarBrowser( settings.value("Home", "/home").toString() );
-    else
+    FileDelegate *pluginDelegate = new FileDelegate(this,multi,color1,color2);
+    ui->listWidget->setItemDelegate(pluginDelegate);
+
+    if ( openfolder != "" )
         CargarBrowser( openfolder );
+    else if ( settings.value("Start", "device").toString() == "device" )
+        checkDevice();
+    else
+        CargarBrowser( settings.value("Home", "/home").toString() );
 
     connect(watcher, SIGNAL(directoryChanged(const QString)), this, SLOT(dirChanged(const QString)));
 
@@ -172,6 +177,104 @@ MainWindow::~MainWindow()
     if ( QFileInfo("/home/user/MyDocs/.tempfile").exists() ) system("rm /home/user/MyDocs/.tempfile");
 }
 
+void MainWindow::checkDevice()
+{
+    QSettings settings( "/etc/hildon/theme/index.theme", QSettings::IniFormat );
+    QString currtheme = settings.value("X-Hildon-Metatheme/IconTheme","hicolor").toString();
+
+    CargarBrowser("_DEVICE_");
+    sPath = "/";
+
+    QFile data( "/etc/mtab" );
+    if (data.open(QFile::ReadOnly | QFile::Truncate))
+    {
+        procesos.clear();
+        QTextStream out(&data);
+        while ( !out.atEnd() )
+        {
+            QString line = out.readLine();
+            if ( line.startsWith("/dev") )
+            {
+                QString line2 = line;
+                int i = line.indexOf(" ");
+                line.remove(i,line.length()-i);
+                line2.remove(0,i+1);
+                i = line2.indexOf(" ");
+                line2.remove(i,line2.length()-i);
+
+                if ( line2 != "/home" )
+                {
+                    QListWidgetItem *item1 = new QListWidgetItem();
+                    item1->setData(Qt::DisplayRole, line);
+                    item1->setStatusTip(line2.remove(0,1));
+                    item1->setData(Qt::UserRole+10," ");
+
+                    if ( line2 == "home/user/MyDocs" )
+                        item1->setData(Qt::UserRole+2,"/usr/share/icons/"+currtheme+"/48x48/hildon/general_device_root_folder.png");
+                    else if ( line2.contains("media/mmc") )
+                        item1->setData(Qt::UserRole+2,"/usr/share/icons/"+currtheme+"/48x48/hildon/general_removable_memory_card.png");
+                    else
+                        item1->setData(Qt::UserRole+2,"/usr/share/icons/"+currtheme+"/48x48/hildon/filemanager_removable_storage.png");
+
+                    ui->listWidget->addItem(item1);
+                    ui->listWidget->item(ui->listWidget->count()-1)->setHidden(true);
+
+                    procesos += QString("blkid " + line);
+
+                }
+            }
+
+        }
+    }
+    data.close();
+    execDevice();
+
+}
+
+void MainWindow::execDevice()
+{
+        proc = new QProcess(this);
+        connect ( proc, SIGNAL(finished(int)), this, SLOT(checkFinished(int)) );
+        proc->start(procesos.at(0));
+        //qDebug() << "Processing: " << procesos.at(0);
+}
+
+void MainWindow::checkFinished(int)
+{
+    QString str = proc->readAllStandardOutput();
+    QString str2 = str;
+
+    if ( !str.contains("LABEL=") )
+    {
+        if ( str.contains("/dev/mmcblk") )
+            str = tr("Memory Card");
+        else
+            str = tr("Removable device");
+    }
+    else
+    {
+        int i = str2.indexOf(":");
+        str2.remove(i,str2.length()-i);
+        i = str.indexOf("LABEL=");
+        str.remove(0,i+7);
+        i = str.indexOf("\"");
+        str.remove(i,str.length()-i);
+    }
+
+    for (int i=0; i<ui->listWidget->count(); ++i)
+    {
+        if ( str2.contains(ui->listWidget->item(i)->data(Qt::DisplayRole).toString()) )
+            ui->listWidget->item(i)->setData(Qt::UserRole+10, str);
+            QApplication::processEvents();
+            ui->listWidget->item(i)->setHidden(false);
+    }
+
+    procesos.removeAt(0);
+    if ( !procesos.isEmpty() )
+        execDevice();
+
+}
+
 void MainWindow::checkOrientation()
 {
     QString orient = settings.value("Orientation", "Auto").toString();
@@ -207,7 +310,33 @@ void MainWindow::orientationChanged()
 void MainWindow::CargarBrowser(QString directorio)
 {
     ordenFile = 0;
+
+    ui->listWidget->clear();
+    ui->lineEdit->setVisible(false);
+    ui->search->setText("");
+    ui->swidget->setVisible(false);
+
+    if ( directorio == "_DEVICE_" )
+    {
+        ui->listWidget->setSortingEnabled(false);
+        ui->pushButton->setEnabled(false);
+        ui->v_clipboard->setEnabled(false);
+        ui->h_clipboard->setEnabled(false);
+        ui->barButton->setText(tr(" Devices"));
+        ui->barButton->setValueText("");
+        return;
+
+    }
+    else
+    {
+        ui->listWidget->setSortingEnabled(true);
+        ui->pushButton->setEnabled(true);
+        ui->v_clipboard->setEnabled(true);
+        ui->h_clipboard->setEnabled(true);
+    }
+
     sPath = directorio;
+
     QDir dir ( directorio, "*" );
     if ( !dir.isReadable() )
           return;
@@ -219,16 +348,15 @@ void MainWindow::CargarBrowser(QString directorio)
     }
     else
     {
+        if (directorio.endsWith("/") )
+            directorio.left(directorio.length()-1);
         ui->barButton->setText( " " + QFileInfo(directorio).fileName() );
         ui->barButton->setValueText( " " + QFileInfo(directorio).path() );
     }
-    ui->lineEdit->setVisible(false);
+
     ui->barButton->setVisible(true);
     ui->barButton->setIcon( QPixmap() );
 
-    ui->listWidget->clear();
-
-
     StartThread = 0;
 
     QStringList entries = dir.entryList();
@@ -262,9 +390,6 @@ void MainWindow::CargarBrowser(QString directorio)
         agregarArchivo(list.at(i).absoluteFilePath());
     }
 
-    FileDelegate *pluginDelegate = new FileDelegate(this,multi,color1,color2);
-    ui->listWidget->setItemDelegate(pluginDelegate);
-
     if ( ui->listWidget->count() > 0 ) {
         ui->listWidget->scrollToItem(ui->listWidget->item(0));
         ui->listWidget->clearSelection();
@@ -277,9 +402,6 @@ void MainWindow::CargarBrowser(QString directorio)
         pepe->start();
     }
 
-    ui->search->setText("");
-    ui->swidget->setVisible(false);
-
     settings.setValue("CurrentDir", sPath);
     settings.sync();
 
@@ -651,7 +773,11 @@ void MainWindow::on_listWidget_itemDoubleClicked(QListWidgetItem* item)
 
 void MainWindow::on_pushButton_clicked()
 {
-    if ( sPath == "/" ) return;
+    if ( sPath == "/" )
+    {
+        checkDevice();
+        return;
+    }
     lastPath = sPath;
     QString nPath = sPath;
     int i = nPath.lastIndexOf( "/" );
@@ -1474,6 +1600,8 @@ void MainWindow::keyReleaseEvent(QKeyEvent* k)
     }
     else if ( SymPressed==0 && ui->search->hasFocus()==false )
     {
+        if ( !ui->pushButton->isEnabled() )
+            return;
         ui->swidget->setVisible(true);
         ui->search->setFocus();
         if ( k->key() == 16777219 )
@@ -1574,3 +1702,8 @@ void MainWindow::on_h_full_clicked()
     else
         this->setWindowState(Qt::WindowFullScreen);
 }
+
+void MainWindow::on_pushButton_customContextMenuRequested(QPoint)
+{
+    checkDevice();
+}
